@@ -7,7 +7,7 @@ except ImportError:
 
 
 @lru_cache
-def user_agent(name):
+def user_agent(name=__package__):
     if "." in name:
         name = name.split(".")[0]
     try:
