@@ -23,7 +23,7 @@ def set_distribution(name) -> str:
 try:
     import requests.utils
 except ImportError:
-    logging.debug("requests.utils not found")
+    logger.debug("requests.utils not found")
 else:
 
     def requests_user_agent(*args):
@@ -36,7 +36,7 @@ else:
 try:
     import aiohttp.http
 except ImportError:
-    logging.debug("aiohttp not found")
+    logger.debug("aiohttp not found")
 else:
 
     def aiohttp_user_agent(agent):
@@ -50,7 +50,7 @@ else:
 try:
     import feedparser
 except ImportError:
-    logging("feedparser not found")
+    logger.debug("feedparser not found")
 else:
 
     def feedparser_user_agent(agent):
